@@ -1,4 +1,4 @@
-from pyzeebe.exceptions.pyzeebe_exceptions import PyZeebeException
+from mpyzeebe.exceptions.pyzeebe_exceptions import PyZeebeException
 
 
 class WorkflowNotFound(PyZeebeException):
