@@ -4,8 +4,8 @@ from typing import Dict
 import grpc
 from zeebe_grpc.gateway_pb2 import PublishMessageRequest, PublishMessageResponse
 
-from pyzeebe.exceptions import MessageAlreadyExists
-from pyzeebe.grpc_internals.zeebe_adapter_base import ZeebeAdapterBase
+from mpyzeebe.exceptions import MessageAlreadyExists
+from mpyzeebe.grpc_internals.zeebe_adapter_base import ZeebeAdapterBase
 
 
 class ZeebeMessageAdapter(ZeebeAdapterBase):
