@@ -1,5 +1,5 @@
 from typing import Callable
 
-from pyzeebe.job.job import Job
+from mpyzeebe.job.job import Job
 
 TaskDecorator = Callable[[Job], Job]
